@@ -11,10 +11,15 @@ def _default_print(person: str, messages: List[Message], ljust: int) -> None:
     scores = [re.match(DEFAULT_SCORE, m.score).group("score") for m in messages]
     fails = len([s for s in scores if s == "X"])
     success = [int(s) for s in scores if s != "X"]
+    avg_score = (
+        f"Average score: {sum(success) / len(success):.2f} "
+        if len(success) > 0
+        else "No average score "
+    )
     print(
         f"{person.ljust(ljust)}: {len(messages)} games, "
         + f"{fails} failed attempts ({fails / len(messages):.1%}). "
-        + f"Average score: {sum(success) / len(success):.2f} "
+        + avg_score
         + f"for the completed games."
     )
 
